==> agconnect_appmessaging-1.3.0%2B300.tar.gz: lib/src/app_message.dart <==
// Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

part of agconnect_appmessaging;

class AppMessage {
  final String id;
  final int startTime;
  final int endTime;
  final AGCAppMessagingDisplayFrequencyType frequencyType;
  final int frequencyValue;
  final int testFlag;
  final AGCAppMessagingDismissType? dismissType;
  final List<String> triggerEvents;
  final AGCAppMessagingMessageType messageType;
  final CardMessage? cardMessage;
  final BannerMessage? bannerMessage;
  final PictureMessage? pictureMessage;

  AppMessage._(Map<String, dynamic> map)
      : id = map['base']?['id'],
        startTime = map['base']?['startTime'],
        endTime = map['base']?['endTime'],
        frequencyType = AGCAppMessagingDisplayFrequencyType.values[map['base']?['frequencyType'] - 1],
        frequencyValue = map['base']?['frequencyValue'],
        testFlag = map['base']?['testFlag'],
        dismissType = map['dismissType'] == null
            ? null
            : AGCAppMessagingDismissType.values.firstWhere(
                (e) => map['dismissType'] == describeEnum(e),
              ),
        triggerEvents = List<String>.from(map['base']?['triggerEvents']),
        messageType = AGCAppMessagingMessageType.values.firstWhere(
          (e) => map['base']?['messageType'] == describeEnum(e),
          orElse: () => AGCAppMessagingMessageType.UNKNOWN,
        ),
        cardMessage = map['card'] == null ? null : CardMessage._(Map<String, dynamic>.from(map['card'])),
        bannerMessage = map['banner'] == null ? null : BannerMessage._(Map<String, dynamic>.from(map['banner'])),
        pictureMessage = map['picture'] == null ? null : PictureMessage._(Map<String, dynamic>.from(map['picture']));

  @override
  String toString() {
    return '$AppMessage('
        'id: $id, '
        'startTime: $startTime, '
        'endTime: $endTime, '
        'frequencyType: $frequencyType, '
        'frequencyValue: $frequencyValue, '
        'testFlag: $testFlag, '
        'dismissType: $dismissType, '
        'triggerEvents: $triggerEvents, '
        'messageType: $messageType, '
        'cardMessage: ${cardMessage ?? 'null'}, '
        'bannerMessage: ${bannerMessage ?? 'null'}, '
        'pictureMessage: ${pictureMessage ?? 'null'})';
  }
}

==> agconnect_appmessaging-1.5.0%2B300.tar.gz: lib/src/app_message.dart <==
// Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

part of agconnect_appmessaging;

class AppMessage {
  final String id;
  final int startTime;
  final int endTime;
  final AGCAppMessagingDisplayFrequencyType frequencyType;
  final int frequencyValue;
  final int testFlag;
  final AGCAppMessagingDismissType? dismissType;
  final List<String> triggerEvents;
  final AGCAppMessagingMessageType messageType;
  final CardMessage? cardMessage;
  final BannerMessage? bannerMessage;
  final PictureMessage? pictureMessage;

  AppMessage._(Map<String, dynamic> map)
      : id = map['base']?['id'],
        startTime = map['base']?['startTime'],
        endTime = map['base']?['endTime'],
        frequencyType = AGCAppMessagingDisplayFrequencyType
            .values[map['base']?['frequencyType'] - 1],
        frequencyValue = map['base']?['frequencyValue'],
        testFlag = map['base']?['testFlag'],
        dismissType = map['dismissType'] == null
            ? null
            : AGCAppMessagingDismissType.values.firstWhere(
                (e) => map['dismissType'] == describeEnum(e),
              ),
        triggerEvents = List<String>.from(map['base']?['triggerEvents']),
        messageType = AGCAppMessagingMessageType.values.firstWhere(
          (e) => map['base']?['messageType'] == describeEnum(e),
          orElse: () => AGCAppMessagingMessageType.UNKNOWN,
        ),
        cardMessage = map['card'] == null
            ? null
            : CardMessage._(Map<String, dynamic>.from(map['card'])),
        bannerMessage = map['banner'] == null
            ? null
            : BannerMessage._(Map<String, dynamic>.from(map['banner'])),
        pictureMessage = map['picture'] == null
            ? null
            : PictureMessage._(Map<String, dynamic>.from(map['picture']));

  @override
  String toString() {
    return '$AppMessage('
        'id: $id, '
        'startTime: $startTime, '
        'endTime: $endTime, '
        'frequencyType: $frequencyType, '
        'frequencyValue: $frequencyValue, '
        'testFlag: $testFlag, '
        'dismissType: $dismissType, '
        'triggerEvents: $triggerEvents, '
        'messageType: $messageType, '
        'cardMessage: ${cardMessage ?? 'null'}, '
        'bannerMessage: ${bannerMessage ?? 'null'}, '
        'pictureMessage: ${pictureMessage ?? 'null'})';
  }
}
